
*** transpose the data set of provincial populations;
proc transpose data=canada_pop out=tcanada_pop (rename=(col1=pop));
var p1951 p1956 p1961 p1966 p1971 p1976 p1981 p1986 p1991 p1996 p2001;
by province;
run;

*** add the variable year to the transposed data set;
data tcanada_pop;
set tcanada_pop;
year = input(substr(_name_,2,4),4.);
drop _name_;
run;

*** set graphics options (specify the JAVAMETA device driver);
goptions reset=all device=javameta
         ftext='Helvetica' htext=3 gunit=pct
         colors=(blue);

*** choose a symbol and axis characteristics;
symbol1 h=2 f=marker v='C' i=join;

axis1 label=('YEAR') order=1951 to 2001 by 5 offset=(5,5)pct minor=none;
axis2 label=(j=l 'POPULATION' j=l '(1000s)') minor=none;

footnote j=r 'PLACE CURSOR ON ANY TRIANGLE TO SEE YEARLY POPULATION ';

*** a macro that creates one plot for Canada and each province;
%macro plots;
*** choose the data for each plot (11 observations for Canada and each provinvce);
%do firstobs=1 %to 133 %by 11;

data temp;
set tcanada_pop (firstobs=&firstobs obs=%eval(&firstobs+10)) end=last;
popup = 'tip=[' || quote('POPULATION (1000s): ' || put(pop,comma.)) || ']';
*** create two macro variables, one is he province number, the other is the province name;
if last then do;
   call symput('provnumb',put(province,2.));
   call symput('provname',put(province,$province.));
end;
drop province;
run;

ods html file="z:\provplot&provnumb..html" 
         parameters=("ZoomControlEnabled"="false" "DataTipStyle"="stick_fixed");   

title h=5 "%trim(&provname)";
proc gplot data=temp;
plot pop*year / haxis=axis1 vaxis=axis2 noframe html=popup;
format pop comma.;
run; 
quit;

ods html close;

%end;
%mend;

*** use the macro to create the plots;
ods listing close;
%plots;
ods listing;
